@@ -11,6 +11,7 @@ import os
 import time
 import xml.etree.ElementTree as ET
 import re
+from collections import OrderedDict
 
 
 # Workaround to support the correct input for both Python 2 and 3. Always use
@@ -26,6 +27,13 @@ class Config:
         self.email = email
         self.token = token
         self.organization = organization
+        self.default_headers = {
+            'X-User-Email': self.email,
+            'X-User-Token': self.token,
+            'Content-Type': 'application/json',
+            'Accept': 'application/json',
+            }
+
 
     @staticmethod
     def from_file(path):
@@ -33,6 +41,7 @@ class Config:
             cfg = json.loads(f.read())
             return Config(**cfg)
 
+
     def save(self, path):
         with click.open_file(expanduser(path), 'w') as f:
             f.write(json.dumps({
@@ -42,31 +51,29 @@ class Config:
                 'api_root': self.api_root,
                 }, indent=2))
 
+
     def url(self, path):
         return "%s/%s/%s" % (self.api_root, self.organization, path)
 
+
     def post(self, path, **kwargs):
-        default_headers = {
-            'X-User-Email': self.email,
-            'X-User-Token': self.token,
-            'Content-Type': 'application/json',
-            'Accept': 'application/json',
-            }
+        default_headers = self.default_headers
         default_headers.update(kwargs.pop('headers', {}))
         return requests.post(self.url(path), headers=default_headers, **kwargs)
 
 
     def get(self, path, **kwargs):
-        default_headers = {
-            'X-User-Email': self.email,
-            'X-User-Token': self.token,
-            'Content-Type': 'application/json',
-            'Accept': 'application/json',
-            }
+        default_headers = self.default_headers
         default_headers.update(kwargs.pop('headers', {}))
         return requests.get(self.url(path), headers=default_headers, **kwargs)
 
 
+    def delete(self, path, **kwargs):
+        default_headers = self.default_headers
+        default_headers.update(kwargs.pop('headers', {}))
+        return requests.delete(self.url(path), headers=default_headers, **kwargs)
+
+
 @click.group()
 @click.option('--apiroot', default=None)
 @click.option('--config',
@@ -89,6 +96,7 @@ def cli(ctx, apiroot, config, organization):
                        "`transcriptic login` ...")
             ctx.invoke(login)
 
+
 @cli.command()
 @click.argument('file', default='-')
 @click.option('--project', '-p',
@@ -262,20 +270,31 @@ def upl(ctx, archive, package):
 def packages(ctx, i):
     '''List packages in your organizaiton'''
     response = ctx.obj.get('/packages/')
-    package_names = {}
+    # there's probably a better way to do this
+    package_names = OrderedDict(sorted({"yours": {}, "theirs": {}}.items(), key=lambda t: len(t[0])))
+
     if response.status_code == 200:
         for pack in response.json():
-            package_names[str(pack['name']).lower().replace("com.%s." % ctx.obj.organization, "")] = str(pack['id'])
+            if pack.get('owner'):
+                if pack['owner']['email'] == ctx.obj.email:
+                    package_names['yours'][str(pack['name']).lower().replace("com.%s." % ctx.obj.organization, "")] = str(pack['id'])
+            else:
+                package_names['theirs'][str(pack['name']).lower().replace("com.%s." % ctx.obj.organization, "")] = str(pack['id'])
     if i:
-        return package_names
+        return dict(package_names['yours'].items() + package_names['theirs'].items())
     else:
-        click.echo('{:^40}'.format("PACKAGE NAME") + "|" +
-                   '{:^40}'.format("PACKAGE ID"))
-        click.echo('{:-^80}'.format(''))
-        for name, id in package_names.items():
-            click.echo('{:<40}'.format(name) + "|" +
-                       '{:^40}'.format(id))
+        for category, packages in package_names.items():
+            if category == "yours":
+                click.echo('\n{:^80}'.format("YOUR PACKAGES:"))
+            else:
+                click.echo('\n{:^80}'.format("OTHER PACKAGES IN YOUR ORG:"))
+            click.echo('{:^40}'.format("PACKAGE NAME") + "|" +
+                       '{:^40}'.format("PACKAGE ID"))
             click.echo('{:-^80}'.format(''))
+            for name, id in packages.items():
+                click.echo('{:<40}'.format(name) + "|" +
+                           '{:^40}'.format(id))
+                click.echo('{:-^80}'.format(''))
 
 @cli.command("new-package")
 @click.argument('name')
@@ -329,8 +348,9 @@ def projects(ctx, i):
 
 @cli.command("new-project")
 @click.argument('name')
+@click.option('dev', '-d', help="Create a pilot project", is_flag=True)
 @click.pass_context
-def new_project(ctx, name):
+def new_project(ctx, name, dev):
     '''Create a new empty project'''
     existing = ctx.obj.get('')
     for p in existing.json()['projects']:
@@ -338,19 +358,36 @@ def new_project(ctx, name):
             click.echo("You already have an existing project with the name \"%s\"."
                        "  Please choose a different project name." % name)
             return
-    new_proj = ctx.obj.post('',
-                            data= json.dumps({
-                                "name": name
-                             })
-                            )
+    proj_data = {"name": name}
+    if dev:
+        proj_data["is_developer"] = True
+    new_proj = ctx.obj.post('', data= json.dumps(proj_data))
     if new_proj.status_code == 201:
-        click.echo("New project '%s' created with id %s  \nView it at %s" %
-                    (name, new_proj.json()['id'],
-                    ctx.obj.url('projects/%s' % new_proj.json()['id'])))
+        click.echo("New%s project '%s' created with id %s  \nView it at %s" %
+                    (" pilot" if dev else "", name, new_proj.json()['id'],
+                    ctx.obj.url('%s' % (new_proj.json()['id']))))
     else:
         click.echo("There was an error creating this package.")
 
 
+@cli.command("delete-project")
+@click.argument('name')
+@click.option('force', '-f', help="force delete a project without being prompted if you're sure", is_flag=True)
+@click.pass_context
+def delete_project(ctx, name, force):
+    '''Delete an existing package'''
+    id = get_project_id(name)
+    if id:
+        if not force:
+            click.confirm("Are you sure you want to permanently delete '%s'?" % get_project_name(id),
+                          default=False,
+                          abort=True)
+        dele = ctx.obj.delete('%s' % id, data=json.dumps({"id": id}))
+
+        click.echo("Project deleted.")
+
+
+
 @cli.command()
 def init():
     '''Initialize directory with blank manifest.json file'''
@@ -571,12 +608,25 @@ def get_project_id(ctx, name):
     if not id:
         id = name if name in projs.values() else None
         if not id:
-            click.echo("A project with the name or id '%s' was not found in your "
+            click.echo("A project with the name '%s' was not found in your "
                        "organization." % name)
             return
     return id
 
 
+@click.pass_context
+def get_project_name(ctx, id):
+    projs = {v:k for k,v in ctx.invoke(projects, i=True).items()}
+    name = projs.get(id)
+    if not name:
+        name = id if name in projs.keys() else None
+        if not name:
+            click.echo("A project with the id '%s' was not found in your "
+                       "organization." % name)
+            return
+    return name
+
+
 @click.pass_context
 def get_package_id(ctx, name):
     package_names = ctx.invoke(packages, i=True)
